import React from 'react'
import ReactDOM from 'react-dom/client'
import {
  createBrowserRouter,
  RouterProvider,
} from 'react-router-dom'
import '@/assets/global.css'
import App from '@/views/App'
import HotelList from '@/views/hotel/List'
import HotelDetail from '@/views/hotel/Detail'
import ErrorPage from '@/components/ErrorPage'

import { ThemeContext } from '@/stores/ThemeContext'
import { isNotEmpty } from '@/utils/commons'

const { createRoot } = ReactDOM

const initRouter = async () => {
  return createBrowserRouter([
    {
      path: '/',
      element: <App />,
      errorElement: <ErrorPage />,
      children: [
        { index: true, element: <HotelList /> },
        { path: 'hotel/list', element: <HotelList /> },
        { path: 'hotel/:hotelId/:checkin/:checkout', element: <HotelDetail /> },
      ]
    }
  ])
}

const initAppliction = async () => {

  const router = await initRouter()

  createRoot(document.getElementById('root')).render(
    //<React.StrictMode>
    <ThemeContext.Provider value={{ colorPrimary: '#00b96b', borderRadius: 4 }}>
      <RouterProvider
        router={router}
        fallbackElement={() => <div>Loading...</div>}
      />
    </ThemeContext.Provider>
    //</React.StrictMode>
  )
}

initAppliction()
