import { useState, useEffect } from 'react'
import { useParams, useNavigate } from 'react-router-dom'
import { Modal, InputNumber, Form, Typography, DatePicker, Button } from 'antd'
import useHotelStore from '@/stores/Hotel'
import { RoomList } from './HotelComponents'
import dayjs from 'dayjs'
import { isEmpty } from '@/utils/commons'

function Detail() {
  const { hotelId, checkin, checkout } = useParams()

  const [loading, setLoading] = useState(true)
  const [hotelQuotation, setHotelQuotation] = useState({
    hotelName: '',
    roomName: '',
    price: '',
  })

  const navigate = useNavigate()
  const [searchForm] = Form.useForm()
  const [selectedHotel, getRoomListByHotel, roomList] = useHotelStore(
    (state) => [state.selectedHotel, state.getRoomListByHotel, state.roomList],
  )

  useEffect(() => {
    // http://localhost:5175/hotel/416980/2024-09-10/2024-09-11
    if (isEmpty(hotelId) || isEmpty(checkin) || isEmpty(checkout)) {
      console.info('criteria is null')
      setLoading(false)
    } else {
      searchForm.setFieldsValue({
        dataRange: [dayjs(checkin), dayjs(checkout)],
        adultCount: 2,
        roomCount: 1,
      })
      setLoading(true)
      getRoomListByHotel(hotelId, checkin, checkout).finally(() =>
        setLoading(false),
      )
    }
  }, [])

  const handelFormFinish = () => {
    const formValue = searchForm.getFieldValue()
    // setSearchParams({
    //   hotel: formValue.hotelName,
    //   checkin: formValue.dataRange[0].format('YYYY-MM-DD'),
    //   checkout: formValue.dataRange[1].format('YYYY-MM-DD')
    // })

    setLoading(true)
    getRoomListByHotel(
      hotelId,
      formValue.dataRange[0].format('YYYY-MM-DD'),
      formValue.dataRange[1].format('YYYY-MM-DD'),
      formValue.adultCount,
      formValue.roomCount,
    ).finally(() => setLoading(false))
  }

  const handleRoomChange = (room, plan) => {
    const forHtJson = {
      hotelName: selectedHotel.hotel_name,
      roomName: room.RoomName,
      price: plan.Price,
    }
    setHotelQuotation(forHtJson)
    showModal()
    document.getElementById('forHtJson').value = JSON.stringify(forHtJson)
  }

  const [isModalOpen, setIsModalOpen] = useState(false)
  const showModal = () => {
    setIsModalOpen(true)
  }
  const handleOk = () => {
    setIsModalOpen(false)
  }
  const handleCancel = () => {
    setIsModalOpen(false)
  }

  return (
    <div>
      <input type="hidden" id="forHtJson" />
      <Modal
        title="你选择了"
        open={isModalOpen}
        onOk={handleOk}
        onCancel={handleCancel}
        footer={null}
      >
        <p>酒店：{hotelQuotation.hotelName}</p>
        <p>房型：{hotelQuotation.roomName}</p>
        <p>价格：{hotelQuotation.price}</p>
      </Modal>

      <Typography.Title level={4}>{selectedHotel.hotel_name}</Typography.Title>
      <div className="p-2">
        <Form
          name="searchForm"
          form={searchForm}
          layout="inline"
          onFinish={handelFormFinish}
          autoComplete="off"
        >
          <Form.Item
            label={'入住时间'}
            name="dataRange"
            allowclear="false"
            rules={[
              {
                required: true,
                message: '必填',
              },
            ]}
          >
            <DatePicker.RangePicker placeholder={['入住日期', '退房日期']} />
          </Form.Item>
          <Form.Item label={'房间数'} name="roomCount">
            <InputNumber min={1} max={100} />
          </Form.Item>
          <Form.Item label={'人数'} name="adultCount">
            <InputNumber min={1} max={100} />
          </Form.Item>
          <Form.Item>
            <Button type="primary" htmlType="submit">
              搜索
            </Button>
          </Form.Item>
          <Form.Item>
            <Button onClick={() => navigate(-1)}>返回</Button>
          </Form.Item>
        </Form>
      </div>
      <RoomList
        loading={loading}
        onChange={({ room, plan }) => {
          handleRoomChange(room, plan)
        }}
        dataSource={roomList}
      ></RoomList>
    </div>
  )
}

export default Detail
