import { defineConfig } from 'vite'
import react from '@vitejs/plugin-react'
import legacy from '@vitejs/plugin-legacy'
import WindiCSS from 'vite-plugin-windicss'
import packageJson from './package.json'
import dayjs from 'dayjs'

const today = new dayjs().format('YYYY-MM-DD HH:mm:ss')

// https://vitejs.dev/config/
export default defineConfig({
  define: {
    __BUILD_DATE__: JSON.stringify(`${today}`),
    __BUILD_VERSION__: JSON.stringify(`${packageJson.version}`),
  },
	plugins: [
		react(), WindiCSS(),
		legacy({
			targets: ['defaults', 'not IE 11'],
		}),
	],
	server: {
		host: '0.0.0.0',
    port: '5175'
	},
	resolve: {
		alias: {
			'@': '/src',
		},
	},
  build: {
    emptyOutDir: true,
    chunkSizeWarningLimit: 555,
    rollupOptions: {
      output: {
        manualChunks(id) {
          if (id.includes('node_modules')) {
            return 'vendor'
          }
        },
      }
    }
  },
})
